"use strict";

var React = _interopRequireWildcard(require("react"));

var PropTypes = _interopRequireWildcard(require("prop-types"));

var _semanticUiReact = require("semantic-ui-react");

var _enzyme = require("enzyme");

var _LineInput = _interopRequireDefault(require("./LineInput"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

// eslint-disable-next-line @typescript-eslint/no-explicit-any
var onValueChangeMock;
beforeEach(function () {
  onValueChangeMock = jest.fn();
});
describe('propTypes', function () {
  it('should validate prop types', function () {
    // eslint-disable-next-line react/forbid-foreign-prop-types
    var propTypes = _LineInput.default.propTypes;
    expect(propTypes.allowEmptyValue).toBe(PropTypes.bool);
    expect(propTypes.className).toBe(PropTypes.string);
    expect(propTypes.countryCode).toBe(PropTypes.string);
    expect(propTypes.creditCardNumber).toBe(PropTypes.string);
    expect(propTypes.disabled).toBe(PropTypes.bool);
    expect(propTypes.errorText).toBe(PropTypes.string);
    expect(propTypes.errorTextPosition).toBeTruthy();
    expect(propTypes.focus).toBe(PropTypes.bool);
    expect(propTypes.icon).toBe(PropTypes.string);
    expect(propTypes.iconColor).toBe(PropTypes.string);
    expect(propTypes.iconPosition).toBeTruthy();
    expect(propTypes.maxLength).toBe(PropTypes.number);
    expect(propTypes.maxValue).toBe(PropTypes.number);
    expect(propTypes.minLength).toBe(PropTypes.number);
    expect(propTypes.minValue).toBe(PropTypes.number);
    expect(propTypes.onValueChange).toBe(PropTypes.func.isRequired);
    expect(propTypes.placeholder).toBe(PropTypes.string);
    expect(propTypes.size).toBeTruthy();
    expect(propTypes.type).toBe(PropTypes.string);
    expect(propTypes.validation).toBeTruthy();
    expect(propTypes.validationErrorIcon).toBe(PropTypes.string);
    expect(propTypes.validationSuccessIcon).toBe(PropTypes.string);
    expect(propTypes.value).toBe(PropTypes.string.isRequired);
  });
});
describe('defaultProps', function () {
  it('should set default values for optional props', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper.props().allowEmptyValue).toBe(false);
    expect(lineInputWrapper.props().className).toBe(undefined);
    expect(lineInputWrapper.props().countryCode).toBe('');
    expect(lineInputWrapper.props().creditCardNumber).toBe('');
    expect(lineInputWrapper.props().disabled).toBe(false);
    expect(lineInputWrapper.props().errorText).toBe('');
    expect(lineInputWrapper.props().errorTextPosition).toBe('bottom');
    expect(lineInputWrapper.props().focus).toBe(false);
    expect(lineInputWrapper.props().icon).toBe('');
    expect(lineInputWrapper.props().iconColor).toBe(undefined);
    expect(lineInputWrapper.props().iconPosition).toBe('left');
    expect(lineInputWrapper.props().maxLength).toBe(undefined);
    expect(lineInputWrapper.props().maxValue).toBe(undefined);
    expect(lineInputWrapper.props().minLength).toBe(undefined);
    expect(lineInputWrapper.props().minValue).toBe(undefined);
    expect(lineInputWrapper.props().placeholder).toBe('');
    expect(lineInputWrapper.props().size).toBe('small');
    expect(lineInputWrapper.props().type).toBe(undefined);
    expect(lineInputWrapper.props().validation).toBe(undefined);
    expect(lineInputWrapper.props().validationErrorIcon).toBe('');
    expect(lineInputWrapper.props().validationSuccessIcon).toBe('');
  });
});
describe('state', function () {
  it('should set initial state', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper.state('hasValidValue')).toBe(true);
    expect(lineInputWrapper.state('hasFocus')).toBe(false);
    expect(lineInputWrapper.state('hasBeenFocused')).toBe(false);
  });
});
describe('onInputBlur', function () {
  it('it should set hasValidValue in state to true, if no validation is provided', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    expect(lineInputWrapper.state('hasValidValue')).toBe(true);
  });
  it('it should set hasValidValue in state to true, if validation is successful', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "number",
      value: "123"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    expect(lineInputWrapper.state('hasValidValue')).toBe(true);
  });
  it('it should not validate, if value is empty and allowEmptyValue is true', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      allowEmptyValue: true,
      onValueChange: onValueChangeMock,
      validation: "number",
      value: ""
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    expect(lineInputWrapper.state('hasValidValue')).toBe(true);
  });
  it('it should set hasValidValue in state to false and show error in input, if validation fails', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "number",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    lineInputWrapper.update();
    var newInputWrapper = lineInputWrapper.find('input');
    expect(lineInputWrapper.state('hasValidValue')).toBe(false); // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
    // @ts-ignore

    expect(newInputWrapper.props().style.borderBottomColor).toBe('red');
  });
  it('it should show errorText, if validation fails', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      errorText: "errorText",
      onValueChange: onValueChangeMock,
      validation: "number",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    lineInputWrapper.update();
    var labelWrapper = lineInputWrapper.find('div.label');
    expect(labelWrapper).toBeTruthy();
  });
  it('it should show errorText, if validation fails', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      errorText: "errorText",
      onValueChange: onValueChangeMock,
      validation: "number",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    lineInputWrapper.update();
    var divWrapper = lineInputWrapper.find('div').first(); // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
    // @ts-ignore

    expect(divWrapper.props().style.flexDirection).toBe('column');
    var labelWrapper = lineInputWrapper.find('div.label');
    expect(labelWrapper).toBeTruthy();
  });
});
describe('onInputFocus', function () {
  it('should modify state correctly', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "number",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    lineInputWrapper.setState({
      hasValidValue: false
    });
    inputWrapper.simulate('focus');
    expect(lineInputWrapper.state('hasValidValue')).toBe(true);
    expect(lineInputWrapper.state('hasFocus')).toBe(true);
    expect(lineInputWrapper.state('hasBeenFocused')).toBe(true);
  });
});
describe('onInputChange', function () {
  test.each([['def', 'def', 'number'], ['5345123455557777', '5345 1234 5555 7777', 'creditCardNumber'], ['543', '543', 'creditCardNumber'], ['534567', '5345 67', 'creditCardNumber'], ['534567771', '5345 6777 1', 'creditCardNumber'], ['534567771111223', '5345 6777 1111 223', 'creditCardNumber'], ['11', '11 / ', 'creditCardExpiration'], ['11/21', '11 / 21', 'creditCardExpiration'], ['34k', '34', 'creditCardVerificationCode']])('it should call onValueChange', function (value, expectedValue, validation) {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: validation,
      value: ""
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('change', {
      target: {
        value: value
      }
    });
    expect(onValueChangeMock).toHaveBeenCalledWith(expectedValue);
  });
});
describe('getInputType()', function () {
  it('should return type, if type prop is specified', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      type: "password",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    expect(inputWrapper.props().type).toBe('password');
  });
  test.each([['emailAddress', 'email'], ['phoneNumber', 'tel'], ['url', 'url']])('it should return HTML input type according to specified validation type when type is not defined', function (validation, htmlInputType) {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: validation,
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    expect(inputWrapper.props().type).toBe(htmlInputType);
  });
  it('should return "text", if any other validation type is specified', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "usSSN",
      value: "abc"
    }));
    var inputWrapper = lineInputWrapper.find('input');
    expect(inputWrapper.props().type).toBe('text');
  });
});
describe('getIconName()', function () {
  it('should not show validationErrorIcon nor validationSuccessIcon when input has not been focused', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "number",
      validationErrorIcon: "exclamation",
      validationSuccessIcon: "check",
      value: ""
    }));
    var iconWrapper = lineInputWrapper.find(_semanticUiReact.Icon);
    expect(iconWrapper.props().name).toBe('');
  });
  test.each([['', 'exclamation', 'red'], ['xx', 'exclamation', 'red'], ['123', 'check', 'green']])('it should show validationErrorIcon or validationSuccessIcon depending on entered value on input blur', function (value, iconName, color) {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "number",
      validationErrorIcon: "exclamation",
      validationSuccessIcon: "check",
      value: value
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    lineInputWrapper.update();
    var iconWrapper = lineInputWrapper.find(_semanticUiReact.Icon);
    expect(iconWrapper.props().name).toBe(iconName);
    expect(iconWrapper.props().color).toBe(color);
  });
  it('should not show credit card icon when validation is "creditCardNumber" and input is empty', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "creditCardNumber",
      value: ""
    }));
    expect(lineInputWrapper.exists(_semanticUiReact.Icon)).toBe(false);
  });
  test.each([['4444', 'cc visa'], ['5444', 'cc mastercard'], ['3434', 'cc amex'], ['3600', 'cc diners club'], ['6011', 'cc discover'], ['3528', 'cc jcb'], ['9999', 'credit card']])('it should show credit card icon depending on entered value on input blur when validation is "creditCardNumber" ', function (value, iconName) {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validation: "creditCardNumber",
      value: value
    }));
    var inputWrapper = lineInputWrapper.find('input');
    inputWrapper.simulate('focus');
    inputWrapper.simulate('blur');
    lineInputWrapper.update();
    var iconWrapper = lineInputWrapper.find(_semanticUiReact.Icon);
    expect(iconWrapper.props().name).toBe(iconName);
  });
  it('should show icon specified in icon prop', function () {
    var lineInputWrapper = (0, _enzyme.mount)(React.createElement(_LineInput.default, {
      icon: "search",
      onValueChange: onValueChangeMock,
      value: "text"
    }));
    var iconWrapper = lineInputWrapper.find(_semanticUiReact.Icon);
    expect(iconWrapper.props().name).toBe('search');
  });
});
describe('render()', function () {
  it('should render component correctly', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render disabled component correctly', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      disabled: true,
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render focused component correctly', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      focus: true,
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render component with errorTextPosition "right" correctly', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      errorTextPosition: "right",
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render validationErrorIcon correctly on right side', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validationErrorIcon: "exclamation",
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render validationSuccessIcon correctly on right side', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      onValueChange: onValueChangeMock,
      validationSuccessIcon: "check",
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render icon correctly depending on iconPosition and iconColor', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      icon: "search",
      iconColor: "blue",
      iconPosition: "right",
      onValueChange: onValueChangeMock,
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
  it('should render component with additional HTML attributes correctly', function () {
    var lineInputWrapper = (0, _enzyme.shallow)(React.createElement(_LineInput.default, {
      className: "test",
      id: "test1",
      onValueChange: onValueChangeMock,
      style: {
        visibility: 'hidden'
      },
      value: "abc"
    }));
    expect(lineInputWrapper).toMatchSnapshot();
  });
});
//# sourceMappingURL=LineInput.test.js.map